<?php

# FitGallery 0.95
# (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
# http://fitgallery.presi.org
#
# remote info gallery
# args:
# valor - string - gallery name

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#    http://www.gnu.org/licenses/gpl.html

include 'common_sec.php';
include 'config/config-pages.php';
include 'config/config-common.php';

$file=check_input($_GET['valor'],VALID_CHARS);
if ($file=='') exit_error('Remote gallery not found.');
$dirimgs='imgs';

header('Content-type: text/plain');

if (is_dir("$dirgal/$file"))
  {
    include 'scan_gal_dir.php';
    $texto_titulo=strtr(strip_tags(file_get_contents("$dirgal/$file/$titulo")),"\n",'');

    echo $mtime       ."\n";
    echo $subtotal    ."\n";
    echo $numimgs     ."\n";
    echo $primero     ."\n";
    echo $texto_titulo."\n";
  }
else exit_error('Remote gallery not found.');

?>
